@@ -1,13 +1,13 @@
 #!/usr/bin/env python3
 # -*- coding: utf-8 -*-
-"""PyQt5 framework for multithreaded data acquisition and communication with an
-I/O device.
+"""PyQt/PySide framework for multithreaded data acquisition and communication
+with an I/O device.
 """
 __author__ = "Dennis van Gils"
 __authoremail__ = "vangils.dennis@gmail.com"
 __url__ = "https://github.com/Dennis-van-Gils/python-dvg-qdeviceio"
-__date__ = "22-07-2020"
-__version__ = "0.3.0"
+__date__ = "14-09-2022"
+__version__ = "1.1.1"
 # pylint: disable=protected-access
 
 from enum import IntEnum, unique
@@ -22,12 +22,70 @@ import time
 # method code with 'sys.settrace(threading._trace_hook)' when a code
 # coverage test is detected. When no coverage test is detected, it will just
 # pass the original method untouched.
-import sys
 import threading
 from functools import wraps
 
+# Mechanism to support both PyQt and PySide
+# -----------------------------------------
+import os
+import sys
+
+QT_LIB = os.getenv("PYQTGRAPH_QT_LIB")
+PYSIDE = "PySide"
+PYSIDE2 = "PySide2"
+PYSIDE6 = "PySide6"
+PYQT4 = "PyQt4"
+PYQT5 = "PyQt5"
+PYQT6 = "PyQt6"
+
+# pylint: disable=import-error, no-name-in-module
+# fmt: off
+if QT_LIB is None:
+    libOrder = [PYQT5, PYSIDE2, PYSIDE6, PYQT6]
+    for lib in libOrder:
+        if lib in sys.modules:
+            QT_LIB = lib
+            break
+
+if QT_LIB is None:
+    for lib in libOrder:
+        try:
+            __import__(lib)
+            QT_LIB = lib
+            break
+        except ImportError:
+            pass
+
+if QT_LIB is None:
+    raise Exception(
+        "DvG_QDeviceIO requires PyQt5, PyQt6, PySide2 or PySide6; none of "
+        "these packages could be imported."
+    )
+
+if QT_LIB == PYQT5:
+    from PyQt5 import QtCore                               # type: ignore
+    from PyQt5.QtCore import pyqtSlot as Slot              # type: ignore
+    from PyQt5.QtCore import pyqtSignal as Signal          # type: ignore
+elif QT_LIB == PYQT6:
+    from PyQt6 import QtCore                               # type: ignore
+    from PyQt6.QtCore import pyqtSlot as Slot              # type: ignore
+    from PyQt6.QtCore import pyqtSignal as Signal          # type: ignore
+elif QT_LIB == PYSIDE2:
+    from PySide2 import QtCore                             # type: ignore
+    from PySide2.QtCore import Slot                        # type: ignore
+    from PySide2.QtCore import Signal                      # type: ignore
+elif QT_LIB == PYSIDE6:
+    from PySide6 import QtCore                             # type: ignore
+    from PySide6.QtCore import Slot                        # type: ignore
+    from PySide6.QtCore import Signal                      # type: ignore
+
+# fmt: on
+# pylint: enable=import-error, no-name-in-module
+# \end[Mechanism to support both PyQt and PySide]
+# -----------------------------------------------
+
 import numpy as np
-from PyQt5 import QtCore
+
 from dvg_debug_functions import (
     print_fancy_traceback as pft,
     dprint,
@@ -193,7 +251,7 @@ class QDeviceIO(QtCore.QObject):
             :obj:`signal_connection_lost()` mechanism.
     """
 
-    signal_DAQ_updated = QtCore.pyqtSignal()
+    signal_DAQ_updated = Signal()
     """:obj:`PyQt5.QtCore.pyqtSignal`: Emitted by :class:`Worker_DAQ` when its
     :attr:`~Worker_DAQ.DAQ_function` has run and finished, either succesfully or
     not.
@@ -215,20 +273,20 @@ class QDeviceIO(QtCore.QObject):
         decorator.
     """
 
-    signal_jobs_updated = QtCore.pyqtSignal()
+    signal_jobs_updated = Signal()
     """:obj:`PyQt5.QtCore.pyqtSignal`: Emitted by :class:`Worker_jobs` when all
     pending jobs in the queue have been sent out to the device in a response to
     :meth:`send` or :meth:`process_jobs_queue`. See also the tip at
     :obj:`signal_DAQ_updated()`.
     """
 
-    signal_DAQ_paused = QtCore.pyqtSignal()
+    signal_DAQ_paused = Signal()
     """:obj:`PyQt5.QtCore.pyqtSignal`: Emitted by :class:`Worker_DAQ` to confirm
     the worker has entered the `paused` state in a response to
-    :meth:`pause_DAQ`. See also the tip at :obj:`signal_DAQ_updated()`.
+    :meth:`Worker_DAQ.pause`. See also the tip at :obj:`signal_DAQ_updated()`.
     """
 
-    signal_connection_lost = QtCore.pyqtSignal()
+    signal_connection_lost = Signal()
     """:obj:`PyQt5.QtCore.pyqtSignal`: Emitted by :class:`Worker_DAQ` to
     indicate that we have lost connection to the device. This happens when `N`
     consecutive device I/O operations have failed, where `N` equals the argument
@@ -237,7 +295,11 @@ class QDeviceIO(QtCore.QObject):
     """
 
     # Necessary for INTERNAL_TIMER
-    _signal_stop_worker_DAQ = QtCore.pyqtSignal()
+    _request_worker_DAQ_stop = Signal()
+
+    # Necessary for CONTINUOUS
+    _request_worker_DAQ_pause = Signal()
+    _request_worker_DAQ_unpause = Signal()
 
     def __init__(self, dev=None, **kwargs):
         super().__init__(**kwargs)  # Pass **kwargs onto QtCore.QObject()
@@ -334,7 +396,9 @@ class QDeviceIO(QtCore.QObject):
             sys.exit(99)
 
         self.worker_DAQ = Worker_DAQ(qdev=self, **kwargs)
-        self._signal_stop_worker_DAQ.connect(self.worker_DAQ._stop)
+        self._request_worker_DAQ_stop.connect(self.worker_DAQ._stop)
+        self._request_worker_DAQ_pause.connect(self.worker_DAQ.pause)
+        self._request_worker_DAQ_unpause.connect(self.worker_DAQ.unpause)
 
         self._thread_DAQ = QtCore.QThread()
         self._thread_DAQ.setObjectName("%s_DAQ" % self.dev.name)
@@ -373,8 +437,8 @@ class QDeviceIO(QtCore.QObject):
 
     def start(
         self,
-        DAQ_priority=QtCore.QThread.InheritPriority,
-        jobs_priority=QtCore.QThread.InheritPriority,
+        DAQ_priority=QtCore.QThread.Priority.InheritPriority,
+        jobs_priority=QtCore.QThread.Priority.InheritPriority,
     ) -> bool:
         """Start the event loop of all of any created workers.
 
@@ -386,12 +450,12 @@ class QDeviceIO(QtCore.QObject):
                 :const:`PyQt5.QtCore.QThread.TimeCriticalPriority`. Be aware that this
                 is resource heavy, so use sparingly.
 
-                Default: :const:`PyQt5.QtCore.QThread.InheritPriority`.
+                Default: :const:`PyQt5.QtCore.QThread.Priority.InheritPriority`.
 
             jobs_priority (:obj:`PyQt5.QtCore.QThread.Priority`, optional):
                 Like `DAQ_priority`.
 
-                Default: :const:`PyQt5.QtCore.QThread.InheritPriority`.
+                Default: :const:`PyQt5.QtCore.QThread.Priority.InheritPriority`.
 
         Returns:
             True if successful, False otherwise.
@@ -406,12 +470,14 @@ class QDeviceIO(QtCore.QObject):
 
         return success
 
-    def start_worker_DAQ(self, priority=QtCore.QThread.InheritPriority) -> bool:
+    def start_worker_DAQ(
+        self, priority=QtCore.QThread.Priority.InheritPriority
+    ) -> bool:
         """Start the data acquisition with the device by starting the event loop
         of the :attr:`worker_DAQ` thread.
 
         Args:
-            priority (:const:`PyQt5.QtCore.QThread.Priority`, optional):
+            priority (:const:`PyQt5.QtCore.QThread.Priority.Priority`, optional):
                 See :meth:`start` for details.
 
         Returns:
@@ -470,7 +536,7 @@ class QDeviceIO(QtCore.QObject):
         return True
 
     def start_worker_jobs(
-        self, priority=QtCore.QThread.InheritPriority
+        self, priority=QtCore.QThread.Priority.InheritPriority
     ) -> bool:
         """Start maintaining the jobs queue by starting the event loop of the
         :attr:`worker_jobs` thread.
@@ -567,14 +633,14 @@ class QDeviceIO(QtCore.QObject):
                 # The QTimer inside the INTERNAL_TIMER '_do_work()'-routine
                 # /must/ be stopped from within the worker_DAQ thread. Hence,
                 # we must use a signal from out of this different thread.
-                self._signal_stop_worker_DAQ.emit()
+                self._request_worker_DAQ_stop.emit()
 
             elif (
                 self.worker_DAQ._DAQ_trigger == DAQ_TRIGGER.SINGLE_SHOT_WAKE_UP
             ):
                 # The QWaitCondition inside the SINGLE_SHOT_WAKE_UP '_do_work()'
                 # routine will likely have locked worker_DAQ. Hence, a
-                # '_signal_stop_worker_DAQ' signal as above might not get
+                # '_request_worker_DAQ_stop' signal as above might not get
                 # handled by worker_DAQ when emitted from out of this thread.
                 # Instead, we directly call '_stop()' from out of this different
                 # thread, which is perfectly fine for SINGLE_SHOT_WAKE_UP as per
@@ -632,7 +698,7 @@ class QDeviceIO(QtCore.QObject):
 
             # The QWaitCondition inside the SINGLE_SHOT_WAKE_UP '_do_work()'-
             # routine will likely have locked worker_DAQ. Hence, a
-            # '_signal_stop_worker_DAQ' signal might not get handled by
+            # '_request_worker_DAQ_stop' signal might not get handled by
             # worker_DAQ when emitted from out of this thread. Instead,
             # we directly call '_stop()' from out of this different thread,
             # which is perfectly fine as per my design.
@@ -660,7 +726,7 @@ class QDeviceIO(QtCore.QObject):
     #   worker_DAQ related
     # --------------------------------------------------------------------------
 
-    @QtCore.pyqtSlot()
+    @Slot()
     def pause_DAQ(self):
         """Only useful in mode :const:`DAQ_TRIGGER.CONTINUOUS`. Request
         :attr:`worker_DAQ` to pause and stop listening for data. After
@@ -668,9 +734,9 @@ class QDeviceIO(QtCore.QObject):
         :obj:`signal_DAQ_paused()`.
         """
         if self.worker_DAQ is not None:
-            self.worker_DAQ.pause()
+            self._request_worker_DAQ_pause.emit()
 
-    @QtCore.pyqtSlot()
+    @Slot()
     def unpause_DAQ(self):
         """Only useful in mode :const:`DAQ_TRIGGER.CONTINUOUS`. Request
         :attr:`worker_DAQ` to resume listening for data. Once
@@ -678,9 +744,9 @@ class QDeviceIO(QtCore.QObject):
         :obj:`signal_DAQ_updated()` for every DAQ update.
         """
         if self.worker_DAQ is not None:
-            self.worker_DAQ.unpause()
+            self._request_worker_DAQ_unpause.emit()
 
-    @QtCore.pyqtSlot()
+    @Slot()
     def wake_up_DAQ(self):
         """Only useful in mode :const:`DAQ_TRIGGER.SINGLE_SHOT_WAKE_UP`.
         Request :attr:`worker_DAQ` to wake up and perform a single update,
@@ -695,7 +761,7 @@ class QDeviceIO(QtCore.QObject):
     #   worker_jobs related
     # --------------------------------------------------------------------------
 
-    @QtCore.pyqtSlot()
+    @Slot()
     def send(self, instruction, pass_args=()):
         """Put a job on the :attr:`worker_jobs` queue and send out the full
         queue first-in, first-out to the device until empty. Once finished, it
@@ -731,7 +797,7 @@ class QDeviceIO(QtCore.QObject):
         if self.worker_jobs is not None:
             self.worker_jobs.send(instruction, pass_args)
 
-    @QtCore.pyqtSlot()
+    @Slot()
     def add_to_jobs_queue(self, instruction, pass_args=()):
         """Put a job on the :attr:`worker_jobs` queue.
 
@@ -740,7 +806,7 @@ class QDeviceIO(QtCore.QObject):
         if self.worker_jobs is not None:
             self.worker_jobs.add_to_queue(instruction, pass_args)
 
-    @QtCore.pyqtSlot()
+    @Slot()
     def process_jobs_queue(self):
         """Send out the full :attr:`worker_jobs` queue first-in, first-out to
         the device until empty. Once finished, it will emit
@@ -856,14 +922,14 @@ class Worker_DAQ(QtCore.QObject):
             Only useful in mode :const:`DAQ_TRIGGER.INTERNAL_TIMER`.
             The update interval is timed to a :class:`PyQt5.QtCore.QTimer`
             running inside :class:`Worker_DAQ`. The default value
-            :const:`PyQt5.QtCore.Qt.PreciseTimer` tries to ensure the best
+            :const:`PyQt5.QtCore.Qt.TimerType.PreciseTimer` tries to ensure the best
             possible timer accuracy, usually ~1 ms granularity depending on the
             OS, but it is resource heavy so use sparingly. One can reduce the
             CPU load by setting it to less precise timer types
-            :const:`PyQt5.QtCore.Qt.CoarseTimer` or
-            :const:`PyQt5.QtCore.Qt.VeryCoarseTimer`.
+            :const:`PyQt5.QtCore.Qt.TimerType.CoarseTimer` or
+            :const:`PyQt5.QtCore.Qt.TimerType.VeryCoarseTimer`.
 
-            Default: :const:`PyQt5.QtCore.Qt.PreciseTimer`.
+            Default: :const:`PyQt5.QtCore.Qt.TimerType.PreciseTimer`.
 
             .. _`arg_critical_not_alive_count`:
 
@@ -912,7 +978,7 @@ class Worker_DAQ(QtCore.QObject):
         DAQ_trigger=DAQ_TRIGGER.INTERNAL_TIMER,
         DAQ_function=None,
         DAQ_interval_ms=100,
-        DAQ_timer_type=QtCore.Qt.PreciseTimer,
+        DAQ_timer_type=QtCore.Qt.TimerType.PreciseTimer,
         critical_not_alive_count=1,
         debug=False,
         **kwargs,
@@ -970,8 +1036,19 @@ class Worker_DAQ(QtCore.QObject):
             )
 
     @_coverage_resolve_trace
-    @QtCore.pyqtSlot()
+    @Slot()
     def _do_work(self):
+        # fmt: off
+        # Uncomment block to enable Visual Studio Code debugger to have access
+        # to this thread. DO NOT LEAVE BLOCK UNCOMMENTED: Running it outside of
+        # the debugger causes crashes.
+        """
+        if self.debug:
+            import pydevd
+            pydevd.settrace(suspend=False)
+        """
+        # fmt: on
+
         init = True
 
         def confirm_has_started(self):
@@ -1045,13 +1122,16 @@ class Worker_DAQ(QtCore.QObject):
             # Wait a tiny amount for the other thread to have entered the
             # QWaitCondition lock, before giving a wakingAll().
             QtCore.QTimer.singleShot(
-                100, self.qdev._qwc_worker_DAQ_stopped.wakeAll,
+                100,
+                self.qdev._qwc_worker_DAQ_stopped.wakeAll,
             )
             self._has_stopped = True
 
         # CONTINUOUS
         elif self._DAQ_trigger == DAQ_TRIGGER.CONTINUOUS:
             while self._running:
+                QtCore.QCoreApplication.processEvents()  # Essential to fire and process signals
+
                 if init:
                     self._pause = True
                     self._paused = True
@@ -1101,16 +1181,14 @@ class Worker_DAQ(QtCore.QObject):
             # in a different thread than this one, to have entered the
             # QWaitCondition lock, before giving a wakingAll().
             QtCore.QTimer.singleShot(
-                100, self.qdev._qwc_worker_DAQ_stopped.wakeAll,
+                100,
+                self.qdev._qwc_worker_DAQ_stopped.wakeAll,
             )
             self._has_stopped = True
 
     @_coverage_resolve_trace
-    @QtCore.pyqtSlot()
+    @Slot()
     def _perform_DAQ(self):
-        # if not self._has_started:  # TODO: Might be obsolete. Scheduled for remove.
-        #    return
-
         locker = QtCore.QMutexLocker(self.dev.mutex)
         self.qdev.update_counter_DAQ += 1
 
@@ -1121,40 +1199,6 @@ class Worker_DAQ(QtCore.QObject):
                 self.debug_color,
             )
 
-        # ----------------------------------
-        #   User-supplied DAQ function
-        # ----------------------------------
-
-        if self.DAQ_function is not None:
-            try:
-                success = self.DAQ_function()
-            except Exception as err:  # pylint: disable=broad-except
-                pft(err)
-                dprint(
-                    "@ Worker_DAQ %s\n" % self.dev.name, ANSI.RED,
-                )
-            else:
-                if success:
-                    # Did return True, hence was successfull
-                    # --> Reset the 'not alive' counter
-                    self.qdev.not_alive_counter_DAQ = 0
-                else:
-                    # Did return False, hence was unsuccessfull
-                    self.qdev.not_alive_counter_DAQ += 1
-
-        # ----------------------------------
-        #   End user-supplied DAQ function
-        # ----------------------------------
-
-        if self.debug:
-            tprint(
-                "Worker_DAQ  %s: unlock # %i"
-                % (self.dev.name, self.qdev.update_counter_DAQ),
-                self.debug_color,
-            )
-
-        locker.unlock()
-
         # Keep track of the obtained DAQ interval and DAQ rate
         if not self._QET_interval.isValid():
             self._QET_interval.start()
@@ -1178,6 +1222,41 @@ class Worker_DAQ(QtCore.QObject):
 
                 self._rate_accumulator = 0
 
+        # ----------------------------------
+        #   User-supplied DAQ function
+        # ----------------------------------
+
+        if self.DAQ_function is not None:
+            try:
+                success = self.DAQ_function()
+            except Exception as err:  # pylint: disable=broad-except
+                pft(err)
+                dprint(
+                    "@ Worker_DAQ %s\n" % self.dev.name,
+                    ANSI.RED,
+                )
+            else:
+                if success:
+                    # Did return True, hence was successfull
+                    # --> Reset the 'not alive' counter
+                    self.qdev.not_alive_counter_DAQ = 0
+                else:
+                    # Did return False, hence was unsuccessfull
+                    self.qdev.not_alive_counter_DAQ += 1
+
+        # ----------------------------------
+        #   End user-supplied DAQ function
+        # ----------------------------------
+
+        if self.debug:
+            tprint(
+                "Worker_DAQ  %s: unlock # %i"
+                % (self.dev.name, self.qdev.update_counter_DAQ),
+                self.debug_color,
+            )
+
+        locker.unlock()
+
         # Check the not alive counter
         if self.qdev.not_alive_counter_DAQ >= self.critical_not_alive_count:
             dprint(
@@ -1191,10 +1270,9 @@ class Worker_DAQ(QtCore.QObject):
 
         self.qdev.signal_DAQ_updated.emit()
 
-    @QtCore.pyqtSlot()
+    @Slot()
     def _stop(self):
-        """Stop the worker to prepare for quitting the worker thread.
-        """
+        """Stop the worker to prepare for quitting the worker thread."""
         if self.debug:
             tprint("Worker_DAQ  %s: stopping" % self.dev.name, self.debug_color)
 
@@ -1211,7 +1289,8 @@ class Worker_DAQ(QtCore.QObject):
             # Wait a tiny amount for the other thread to have entered the
             # QWaitCondition lock, before giving a wakingAll().
             QtCore.QTimer.singleShot(
-                100, self.qdev._qwc_worker_DAQ_stopped.wakeAll,
+                100,
+                self.qdev._qwc_worker_DAQ_stopped.wakeAll,
             )
             self._has_stopped = True
 
@@ -1226,12 +1305,14 @@ class Worker_DAQ(QtCore.QObject):
     #   pause / unpause
     # ----------------------------------------------------------------------
 
-    @QtCore.pyqtSlot()
+    @Slot()
     def pause(self):
-        """Only useful in mode :const:`DAQ_TRIGGER.CONTINUOUS`. See the
-        description at :meth:`QDeviceIO.pause_DAQ`.
+        """Only useful in mode :const:`DAQ_TRIGGER.CONTINUOUS`. Pause
+        the worker to stop listening for data. After :attr:`worker_DAQ` has
+        achieved the `paused` state, it will emit :obj:`signal_DAQ_paused()`.
 
-        This method can be called from another thread.
+        This method should not be called from another thread. Connect this slot
+        to a signal instead.
         """
         if self._DAQ_trigger == DAQ_TRIGGER.CONTINUOUS:
             if self.debug:
@@ -1245,12 +1326,15 @@ class Worker_DAQ(QtCore.QObject):
             # '_do_work()' as per my design.
             self._pause = True
 
-    @QtCore.pyqtSlot()
+    @Slot()
     def unpause(self):
-        """Only useful in mode :const:`DAQ_TRIGGER.CONTINUOUS`. See the
-        description at :meth:`QDeviceIO.unpause_DAQ`.
+        """Only useful in mode :const:`DAQ_TRIGGER.CONTINUOUS`. Unpause
+        the worker to resume listening for data. Once :attr:`worker_DAQ` has
+        successfully resumed, it will emit :obj:`signal_DAQ_updated()` for every
+        DAQ update.
 
-        This method can be called from another thread.
+        This method should not be called from another thread. Connect this slot
+        to a signal instead.
         """
         if self._DAQ_trigger == DAQ_TRIGGER.CONTINUOUS:
             if self.debug:
@@ -1268,7 +1352,7 @@ class Worker_DAQ(QtCore.QObject):
     #   wake_up
     # ----------------------------------------------------------------------
 
-    @QtCore.pyqtSlot()
+    @Slot()
     def wake_up(self):
         """Only useful in mode :const:`DAQ_TRIGGER.SINGLE_SHOT_WAKE_UP`. See the
         description at :meth:`QDeviceIO.wake_up_DAQ`.
@@ -1404,7 +1488,11 @@ class Worker_jobs(QtCore.QObject):
     """
 
     def __init__(
-        self, qdev, jobs_function=None, debug=False, **kwargs,
+        self,
+        qdev,
+        jobs_function=None,
+        debug=False,
+        **kwargs,
     ):
         super().__init__(**kwargs)  # Pass **kwargs onto QtCore.QObject()
         self.debug = debug
@@ -1435,8 +1523,19 @@ class Worker_jobs(QtCore.QObject):
             )
 
     @_coverage_resolve_trace
-    @QtCore.pyqtSlot()
+    @Slot()
     def _do_work(self):
+        # fmt: off
+        # Uncomment block to enable Visual Studio Code debugger to have access
+        # to this thread. DO NOT LEAVE BLOCK UNCOMMENTED: Running it outside of
+        # the debugger causes crashes.
+        """
+        if self.debug:
+            import pydevd
+            pydevd.settrace(suspend=False)
+        """
+        # fmt: on
+
         init = True
 
         def confirm_has_started(self):
@@ -1496,22 +1595,21 @@ class Worker_jobs(QtCore.QObject):
 
         if self.debug:
             tprint(
-                "Worker_jobs %s: has stopped" % self.dev.name, self.debug_color,
+                "Worker_jobs %s: has stopped" % self.dev.name,
+                self.debug_color,
             )
 
         # Wait a tiny amount for the other thread to have entered the
         # QWaitCondition lock, before giving a wakingAll().
         QtCore.QTimer.singleShot(
-            100, self.qdev._qwc_worker_jobs_stopped.wakeAll,
+            100,
+            self.qdev._qwc_worker_jobs_stopped.wakeAll,
         )
         self._has_stopped = True
 
     @_coverage_resolve_trace
-    @QtCore.pyqtSlot()
+    @Slot()
     def _perform_jobs(self):
-        # if not self._has_started:  # TODO: Might be obsolete. Scheduled for remove.
-        #    return
-
         locker = QtCore.QMutexLocker(self.dev.mutex)
         self.qdev.update_counter_jobs += 1
 
@@ -1553,7 +1651,8 @@ class Worker_jobs(QtCore.QObject):
                     except Exception as err:  # pylint: disable=broad-except
                         pft(err)
                         dprint(
-                            "@ Worker_jobs %s\n" % self.dev.name, ANSI.RED,
+                            "@ Worker_jobs %s\n" % self.dev.name,
+                            ANSI.RED,
                         )
                 else:
                     # User-supplied job processing
@@ -1572,13 +1671,13 @@ class Worker_jobs(QtCore.QObject):
         locker.unlock()
         self.qdev.signal_jobs_updated.emit()
 
-    @QtCore.pyqtSlot()
+    @Slot()
     def _stop(self):
-        """Stop the worker to prepare for quitting the worker thread
-        """
+        """Stop the worker to prepare for quitting the worker thread"""
         if self.debug:
             tprint(
-                "Worker_jobs %s: stopping" % self.dev.name, self.debug_color,
+                "Worker_jobs %s: stopping" % self.dev.name,
+                self.debug_color,
             )
 
         self._running = False
